Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1313)

Unified Diff: remoting/protocol/host_event_dispatcher.h

Issue 9646013: Add the plumbing that will carry a clipboard item from a chromoting client to a host. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 8 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: remoting/protocol/host_event_dispatcher.h
diff --git a/remoting/protocol/host_event_dispatcher.h b/remoting/protocol/host_event_dispatcher.h
index 7076af1c6a6845cbc74fdf3fad4af74ec8557197..438d743a504f9d3cecefbfabc67ddd93189b9724 100644
--- a/remoting/protocol/host_event_dispatcher.h
+++ b/remoting/protocol/host_event_dispatcher.h
@@ -11,11 +11,12 @@
namespace remoting {
namespace protocol {
+class ClipboardStub;
class EventMessage;
class InputStub;
// HostEventDispatcher dispatches incoming messages on the event
// channel to InputStub.
class HostEventDispatcher : public ChannelDispatcherBase {
public:
typedef base::Callback<void(int64)> SequenceNumberCallback;
@@ -23,6 +24,13 @@ class HostEventDispatcher : public ChannelDispatcherBase {
HostEventDispatcher();
virtual ~HostEventDispatcher();
+ // Set the ClipboardStub that will be called for each incoming clipboard
+ // message. Doesn't take ownership of |clipboard_stub|. It must outlive
+ // the dispatcher.
+ void set_clipboard_stub(ClipboardStub* clipboard_stub) {
Sergey Ulanov 2012/03/09 00:23:41 Would it be better to use control channel for clip
simonmorris 2012/03/09 00:34:14 I think it's better to send clipboard events over
Wez 2012/03/09 00:44:07 We'll have a keyboard-event-specific reliability p
+ clipboard_stub_ = clipboard_stub;
+ }
+
// Set InputStub that will be called for each incoming input
// message. Doesn't take ownership of |input_stub|. It must outlive
// the dispatcher.
@@ -42,6 +50,7 @@ class HostEventDispatcher : public ChannelDispatcherBase {
void OnMessageReceived(EventMessage* message,
const base::Closure& done_task);
+ ClipboardStub* clipboard_stub_;
InputStub* input_stub_;
SequenceNumberCallback sequence_number_callback_;
@@ -11,11 +11,12 @@
class InputStub;
// HostEventDispatcher dispatches incoming messages on the event
-// channel to InputStub.
+// channel to InputStub or ClipboardStub.
class HostEventDispatcher : public ChannelDispatcherBase {
public:

Powered by Google App Engine
This is Rietveld 408576698